# <img src='./logo.svg' card_color="#FF8600" width="50" style="vertical-align:bottom" style="vertical-align:bottom">Synonyms

## Summary
This skill handles setting and calling synonym (aliased) commands.

## Description
You may define a phrase as a synonym for a Neon command. Any time you ask something, this skill will check to see if it 
is a synonym for something else and complete that other action.

## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonDaniel](https://github.com/NeonDaniel)
[NeonGeckoCom](https://github.com/NeonGeckoCom)
[reginaneon](https://github.com/reginaneon)

## Category
**Daily**
Productivity

## Tags
#NeonGecko Original
#NeonAI
#synonym
#alias
#commands